@@ -95,7 +95,7 @@ public:
     // Constructor: we normally look for a configuration file, except
     // if this was specified on the command line and passed through
     // argcnf
-    RclConfig(const string *argcnf = 0);
+    RclConfig(const string *argcnf = nullptr);
 
     RclConfig(const RclConfig &r);
 
@@ -141,9 +141,8 @@ public:
     string getKeyDir() const {return m_keydir;}
 
     /** Get generic configuration parameter according to current keydir */
-    bool getConfParam(const string& name, string& value, 
-                      bool shallow=false) const {
-            if (m_conf == 0)
+    bool getConfParam(const string& name, string& value, bool shallow=false) const {
+            if (nullptr == m_conf)
                 return false;
             return m_conf->get(name, value, m_keydir, shallow);
     }
@@ -153,15 +152,13 @@ public:
     bool getConfParam(const string &name, bool *value, bool shallow=false) const;
     /** Variant with conversion to vector<string>
      *  (stringToStrings). Can fail if the string is malformed. */
-    bool getConfParam(const string &name, vector<string> *value, 
-                      bool shallow=false) const;
+    bool getConfParam(const string &name, vector<string> *value, bool shallow=false) const;
     /** Variant with conversion to unordered_set<string>
      *  (stringToStrings). Can fail if the string is malformed. */
     bool getConfParam(const string &name, std::unordered_set<std::string> *v, 
                       bool shallow=false) const;
     /** Variant with conversion to vector<int> */
-    bool getConfParam(const string &name, vector<int> *value, 
-                      bool shallow=false) const;
+    bool getConfParam(const string &name, vector<int> *value, bool shallow=false) const;
 
     enum ThrStage {ThrIntern=0, ThrSplit=1, ThrDbWrite=2};
     pair<int, int> getThrConf(ThrStage who) const;
@@ -170,7 +167,7 @@ public:
      * Get list of config names under current sk, with possible 
      * wildcard filtering 
      */
-    vector<string> getConfNames(const char *pattern = 0) const {
+    vector<string> getConfNames(const char *pattern = nullptr) const {
         return m_conf->getNames(m_keydir, pattern);
     }
 
@@ -319,7 +316,7 @@ public:
      * use this (ie: mh_mail). The information specific to a given filter
      * is typically stored in a separate section(ie: [mail]) 
      */
-    vector<string> getFieldSectNames(const string &sk, const char* = 0) const;
+    vector<string> getFieldSectNames(const string &sk, const char* = nullptr) const;
     bool getFieldConfParam(const string &name, const string &sk, string &value)
         const;
 
@@ -479,4 +476,10 @@ extern bool o_index_storedoctext;
 // in addition to other issues. See recoll.conf comments. 
 extern bool o_uptodate_test_use_mtime;
 
+// Up to version 1.33.x recoll never stem-expanded terms inside phrase searches. There was actually
+// no obvious reasons for this. The default was not changed, but a modifier was added (x) to allow
+// for on-request phrase expansion. Setting the following to true will change the default behaviour
+// (use 'l' to disable for a specific instance)
+extern bool o_expand_phrases;
+
 #endif /* _RCLCONFIG_H_INCLUDED_ */
