@@ -54,6 +54,8 @@
 #include "log.h"
 #include "smallut.h"
 #include "rclconfig.h"
+#include "damlev.h"
+#include "utf8iter.h"
 
 using namespace std;
 
@@ -279,7 +281,10 @@ const string& path_pkgdatadir()
         "a subfolder of the installation directory. \n"
         "Please set the RECOLL_DATADIR environment variable to point to it\n"
         "(e.g. setx RECOLL_DATADIR \"C:/Program Files (X86)/Recoll/Share)\"\n";
-#elif defined(__APPLE__) && !defined(MACPORTS) && !defined(HOMEBREW)
+#elif defined(__APPLE__) && defined(RECOLL_AS_MAC_BUNDLE)
+    // The package manager builds (Macports, Homebrew, Nixpkgs ...) all arrange to set a proper
+    // compiled value for RECOLL_DATADIR. We can't do this when building a native bundle with
+    // QCreator, in which case we use the executable location.
     uint32_t size = 0;
     _NSGetExecutablePath(nullptr, &size);
     char *path= (char*)malloc(size+1);
@@ -337,47 +342,6 @@ string url_encode(const string& url, string::size_type offs)
     return out;
 }
 
-static inline int h2d(int c) {
-    if ('0' <= c && c <= '9')
-        return c - '0';
-    else if ('A' <= c && c <= 'F')
-        return 10 + c - 'A';
-    else if ('a' <= c && c <= 'f')
-        return 10 + c - 'a';
-    else 
-        return -1;
-}
-
-string url_decode(const string &in)
-{
-    if (in.size() <= 2)
-        return in;
-    string out;
-    out.reserve(in.size());
-    const char *cp = in.c_str();
-    string::size_type i = 0;
-    for (; i < in.size() - 2; i++) {
-        if (cp[i] == '%') {
-            int d1 = h2d(cp[i+1]);
-            int d2 = h2d(cp[i+2]);
-            if (d1 != -1 && d2 != -1) {
-                out += (d1 << 4) + d2;
-            } else {
-                out += '%';
-                out += cp[i+1];
-                out += cp[i+2];
-            }
-            i += 2;
-        } else {
-            out += cp[i];
-        }
-    }
-    while (i < in.size()) {
-        out += cp[i++];
-    }
-    return out;
-}
-
 string url_gpath(const string& url)
 {
     // Remove the access schema part (or whatever it's called)
@@ -537,18 +501,18 @@ const string& tmplocation()
         /* Don't use these under windows because they will return
          * non-ascii non-unicode stuff (would have to call _wgetenv()
          * instead. path_wingetrcltmpdir() will manage */
-        if (tmpdir == 0) {
+        if (tmpdir == nullptr) {
             tmpdir = getenv("TMPDIR");
         }
-        if (tmpdir == 0) {
+        if (tmpdir == nullptr) {
             tmpdir = getenv("TMP");
         }
-        if (tmpdir == 0) {
+        if (tmpdir == nullptr) {
             tmpdir = getenv("TEMP");
         }
 #endif
 
-        if (tmpdir == 0) {
+        if (tmpdir == nullptr) {
 #ifdef _WIN32
             stmpdir = path_wingetrcltmpdir();
 #else
@@ -776,7 +740,7 @@ static const string& xdgcachedir()
     static string xdgcache;
     if (xdgcache.empty()) {
         const char *cp = getenv("XDG_CACHE_HOME");
-        if (cp == 0) {
+        if (nullptr == cp) {
             xdgcache = path_cat(path_home(), ".cache");
         } else {
             xdgcache = string(cp);
@@ -925,6 +889,90 @@ string localelang()
     return locale.substr(0, under);
 }
 
+class IntString {
+public:
+    IntString(const std::string& utf8) {
+        m_len = utf8len(utf8);
+        m_vec = (int*)malloc(m_len * sizeof(int));
+        Utf8Iter it(utf8);
+        int i = 0;
+        for (; !it.eof(); it++) {
+            if (it.error()) {
+                LOGERR("IntString: Illegal seq at byte position " << it.getBpos()  <<"\n");
+                goto error;
+            }
+            unsigned int value = *it;
+            if (value == (unsigned int)-1) {
+                LOGERR("IntString: Conversion error\n");
+                goto error;
+            }
+            if (i >= m_len) {
+                LOGFAT("IntString:: OVERFLOW!?!\n");
+                abort();
+            }
+            m_vec[i++] = value;
+        }
+        return;
+    error:
+        if (m_vec) {
+            free(m_vec);
+            m_vec = nullptr;
+        }
+        m_len = 0;
+    }
+    ~IntString() {
+        if (m_vec)
+            free(m_vec);
+    }
+    int size() const {
+        return m_len;
+    }
+    const int& operator[](int i) const {
+        return m_vec[i];
+    }
+private:
+    int *m_vec{nullptr};
+    int m_len{0};
+};
+
+int u8DLDistance(const std::string& str1, const std::string str2)
+{
+    IntString istr1(str1);
+    IntString istr2(str2);
+    if ((str1.size() && istr1.size() == 0) || (str2.size() && istr2.size() == 0)) {
+        return -1;
+    }
+    return DLDistance(istr1, istr2);
+}
+
+// Extract MIME type from a string looking like: ": text/plain; charset=us-ascii".
+string growmimearoundslash(string mime)
+{
+    string::size_type start;
+    string::size_type nd;
+    // File -i will sometimes return strange stuff (ie: "very small file")
+    if((start = nd = mime.find("/")) == string::npos) {
+        return string();
+    }
+    while (start > 0) {
+        start--;
+        if (!isalpha(mime[start])) {
+            start++;
+            break;
+        }
+    }
+    const static string allowedpunct("+-.");
+    while (nd < mime.size() - 1) {
+        nd++;
+        if (!isalnum(mime[nd]) && allowedpunct.find(mime[nd]) == string::npos) {
+            nd--;
+            break;
+        }
+    }
+    mime = mime.substr(start, nd-start+1);
+    return mime;
+}
+
 void rclutil_init_mt()
 {
     path_pkgdatadir();
