@@ -33,6 +33,6 @@
 extern bool transcode(const std::string &in, std::string &out, 
               const std::string &icode,
               const std::string &ocode, 
-              int *ecnt = 0);
+              int *ecnt = nullptr);
 
 #endif /* _TRANSCODE_H_INCLUDED_ */
